abacusai.llm_generated_code — AbacusAI documentation

# abacusai.llm_generated_code

## Classes

`LlmGeneratedCode` | Code generated by LLM.

## Module Contents

class abacusai.llm_generated_code.LlmGeneratedCode(client, sql=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Code generated by LLM.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - sql (str) – SQL query generated by LLM.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict